@@ -1,7 +1,7 @@
 # flake8: noqa
 # pylint: disable=useless-import-alias,missing-module-docstring
 
-__version__ = "0.10.1"
+__version__ = "1.0.0"
 
 try:
     from markupsafe import escape
@@ -13,7 +13,10 @@ except ImportError:
 from .mode import Mode as Mode
 from .token import Token
 from .expression import Expression
+
 from .loaders import FileSystemLoader
+from .loaders import DictLoader
+from .loaders import ChoiceLoader
 
 from .context import Context
 from .context import Undefined
