@@ -1,4 +1,5 @@
 """Parse tree node and pseudo "tag" for output statements."""
+from typing import Any
 from typing import Optional
 from typing import TextIO
 
@@ -43,9 +44,9 @@ class StatementNode(Node):
     def __repr__(self) -> str:  # pragma: no cover
         return f"StatementNode(tok={self.tok}, expression={self.expression!r})"
 
-    def _to_liquid_string(self, val: object, autoescape: bool) -> str:
-        if isinstance(val, str):
-            # shortcut for common case.
+    # pylint: disable=no-self-use
+    def _to_liquid_string(self, val: Any, autoescape: bool) -> str:
+        if isinstance(val, str) or (autoescape and hasattr(val, "__html__")):
             pass
         elif isinstance(val, bool):
             val = str(val).lower()
@@ -57,17 +58,17 @@ class StatementNode(Node):
             else:
                 val = "".join(soft_str(itm) for itm in val)
         elif isinstance(val, range):
-            val = f"({val.start}..{val.stop - 1})"
+            val = f"{val.start}..{val.stop - 1}"
         else:
             val = str(val)
 
-        assert isinstance(val, str)
-
         if autoescape:
             val = escape(val)
 
+        assert isinstance(val, str)
         return val
 
+    # pylint: disable=useless-return
     def render_to_output(self, context: Context, buffer: TextIO) -> Optional[bool]:
         val = self.expression.evaluate(context)
         buffer.write(self._to_liquid_string(val, context.autoescape))
